@@ -10,7 +10,7 @@ from decimal import Decimal
 
 import proteus.config
 
-__version__ = "6.0.7"
+__version__ = "6.0.8"
 __all__ = ['Model', 'Wizard', 'Report']
 
 _MODELS = threading.local()
@@ -1245,8 +1245,8 @@ class Wizard(object):
 
             self.actions = []
             for action in result.get('actions', []):
-                proteus_action = _convert_action(*action,
-                    context=self._context)
+                proteus_action = _convert_action(
+                    *action, context=self._context, config=self._config)
                 if proteus_action:
                     self.actions.append(proteus_action)
 
